@@ -1,7 +1,8 @@
 """Unit tests for schedule.py"""
-import unittest
-import mock
 import datetime
+import functools
+import mock
+import unittest
 
 # Silence "missing docstring", "method could be a function",
 # "class already defined", and "too many public methods" messages:
@@ -19,7 +20,7 @@ def make_mock_job(name=None):
 
 class mock_datetime(object):
     """
-    monkey-patch datetime for predictable results
+    Monkey-patch datetime for predictable results
     """
     def __init__(self, year, month, day, hour, minute):
         self.year = year
@@ -89,6 +90,13 @@ class SchedulerTests(unittest.TestCase):
             assert every().day.at('09:00').do(mock_job).next_run.day == 7
             assert every().day.at('12:30').do(mock_job).next_run.day == 6
             assert every().week.do(mock_job).next_run.day == 13
+            assert every().monday.do(mock_job).next_run.day == 11
+            assert every().tuesday.do(mock_job).next_run.day == 12
+            assert every().wednesday.do(mock_job).next_run.day == 13
+            assert every().thursday.do(mock_job).next_run.day == 7
+            assert every().friday.do(mock_job).next_run.day == 8
+            assert every().saturday.do(mock_job).next_run.day == 9
+            assert every().sunday.do(mock_job).next_run.day == 10
 
     def test_run_all(self):
         mock_job = make_mock_job()
@@ -111,8 +119,19 @@ class SchedulerTests(unittest.TestCase):
         assert 'job_fun' in s
         assert 'foo' in s
         assert 'bar=23' in s
+
+    def test_to_string_lambda_job_func(self):
         assert len(str(every().minute.do(lambda: 1))) > 1
-        assert len(str(every().day.at("10:30").do(lambda: 1))) > 1
+        assert len(str(every().day.at('10:30').do(lambda: 1))) > 1
+
+    def test_to_string_functools_partial_job_func(self):
+        def job_fun(arg):
+            pass
+        job_fun = functools.partial(job_fun, 'foo')
+        job_repr = repr(every().minute.do(job_fun, bar=True, somekey=23))
+        assert 'functools.partial' in job_repr
+        assert 'bar=True' in job_repr
+        assert 'somekey=23' in job_repr
 
     def test_run_pending(self):
         """Check that run_pending() runs pending jobs.
@@ -131,6 +150,7 @@ class SchedulerTests(unittest.TestCase):
             every().minute.do(mock_job)
             every().hour.do(mock_job)
             every().day.do(mock_job)
+            every().sunday.do(mock_job)
             schedule.run_pending()
             assert mock_job.call_count == 0
 
@@ -148,22 +168,61 @@ class SchedulerTests(unittest.TestCase):
             schedule.run_pending()
             assert mock_job.call_count == 3
 
-    def test_run_every_n_days_at_specific_time(self):
+        with mock_datetime(2010, 1, 10, 13, 16):
+            mock_job.reset_mock()
+            schedule.run_pending()
+            assert mock_job.call_count == 4
+
+    def test_run_every_weekday_at_specific_time_today(self):
         mock_job = make_mock_job()
         with mock_datetime(2010, 1, 6, 13, 16):
-            every(2).days.at("11:30").do(mock_job)
+            every().wednesday.at('14:12').do(mock_job)
             schedule.run_pending()
             assert mock_job.call_count == 0
 
-        with mock_datetime(2010, 1, 7, 13, 16):
-            schedule.run_pending()
-            assert mock_job.call_count == 0
-
-        with mock_datetime(2010, 1, 8, 13, 16):
+        with mock_datetime(2010, 1, 6, 14, 16):
             schedule.run_pending()
             assert mock_job.call_count == 1
 
-        with mock_datetime(2010, 1, 10, 13, 16):
+    def test_run_every_weekday_at_specific_time_past_today(self):
+        mock_job = make_mock_job()
+        with mock_datetime(2010, 1, 6, 13, 16):
+            every().wednesday.at('13:15').do(mock_job)
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 13, 13, 14):
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 13, 13, 16):
+            schedule.run_pending()
+            assert mock_job.call_count == 1
+
+    def test_run_every_n_days_at_specific_time(self):
+        mock_job = make_mock_job()
+        with mock_datetime(2010, 1, 6, 11, 29):
+            every(2).days.at('11:30').do(mock_job)
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 6, 11, 31):
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 7, 11, 31):
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 8, 11, 29):
+            schedule.run_pending()
+            assert mock_job.call_count == 0
+
+        with mock_datetime(2010, 1, 8, 11, 31):
+            schedule.run_pending()
+            assert mock_job.call_count == 1
+
+        with mock_datetime(2010, 1, 10, 11, 31):
             schedule.run_pending()
             assert mock_job.call_count == 2
 
